JOURNAL OF APPLIED BIOMECHANICS, 2005, **21**, 167-180
©2005 Human Kinetics Publishers, Inc.

# **A Simple Method for Measuring** **Stiffness During Running**

_Jean-Benoît Morin_ _\[1\]_ _, Georges Dalleau_ _\[2\]_ _, Heikki Kyröläinen_ _\[3\]_ _,_

_Thibault Jeannin_ _\[1\]_ _, and Alain Belli_ _\[1\]_

_1University of Saint-Etienne; 2University of La Réunion_

_3University of Jyväskylä_

The spring-mass model, representing a runner as a point mass supported by
a single linear leg spring, has been a widely used concept in studies on run­
ning and bouncing mechanics. However, the measurement of leg and vertical
stiffness has previously required force platforms and high-speed kinematic
measurement systems that are costly and difficult to handle in field condi­
tions. We propose a new “sine-wave” method for measuring stiffness during
running. Based on the modeling of the force-time curve by a sine function,
this method allows leg and vertical stiffness to be estimated from just a few
simple mechanical parameters: body mass, forward velocity, leg length, flight
time, and contact time. We compared this method to force-platform-derived
stiffness measurements for treadmill dynamometer and overground running
conditions, at velocities ranging from 3.33 m·s \[–1\] to maximal running velocity
in both recreational and highly trained runners. Stiffness values calculated with
the proposed method ranged from 0.67% to 6.93% less than the force platform
method, and thus were judged to be acceptable. Furthermore, significant linear
regressions ( _p_ \< 0.01) close to the identity line were obtained between force
platform and sine-wave model values of stiffness. Given the limits inherent in
the use of the spring-mass model, it was concluded that this sine-wave method
allows leg and stiffness estimates in running on the basis of a few mechanical
parameters, and could be useful in further field measurements.

_Key Words_ : spring-mass, modeling, practical calculation

During running, the musculoskeletal structures of the legs alternately store
and return elastic energy, so the legs can be described as springs loaded by the
runner’s body mass, constituting the “spring-mass model” (Alexander, 1992; Blick­
han, 1989; Cavagna, Heglund, & Taylor, 1977; Cavagna, Saibene, & Margaria,

1Physiology Laboratory, PPEH Res. Unit, Univ. of Saint-Etienne, CHU Bellevue,
42055 St-Etienne Cedex 02, France; \[2\] Sport Sciences Res. Center, Faculty of Science and
Technology, Univ. of La Réunion, 117 General Ailleret St., 97430 Le Tampon, France;
3Neuromuscular Res. Center, Univ. of Jyväskylä, PO Box 35, 40014 Jyväskylä, Finland.

167

168 _Morin, Dalleau, et al._

1964; McMahon & Cheng, 1990). This model has been a widely used concept for
describing and studying the storage and return of elastic energy in the lower limbs
in humans and other animals during bouncing and running (Dalleau, Belli, Bourdin,
& Lacour, 1998; Farley, Blickhan, Saito, & Taylor, 1991; Farley & Gonzalez, 1996;
Ferris, Louie, & Farley, 1998; He, Kram, & McMahon, 1991; McMahon, Valiant,
& Fredrick, 1987; McMahon & Cheng, 1990). The model consists of a point mass
supported by a single massless linear “leg spring.”

The main mechanical parameter studied when using the spring-mass model
is the stiffness of the leg spring, defined as the ratio of the maximal force in the
spring to the maximum leg compression at the middle of the stance phase (Farley &
Gonzalez, 1996). Moreover, although it does not correspond to any physical spring,
the term vertical stiffness is used to describe the vertical motion of the center of
mass (CM) during contact (Farley & Gonzalez, 1996; McMahon & Cheng, 1990),
and is defined as the ratio of the maximal force to the vertical displacement of the
CM as it reaches its lowest point, i.e., the middle of the stance phase. Maximal
ground reaction force and CM displacement measurements during running are
needed to measure these parameters requiring dynamometers such as overground
or treadmill-mounted force platforms, or even video motion-analysis (e.g., Aram­
patzis, Brüggemann, & Metzler, 1999). Such equipment is costly and not practical
for field measurements.

Considering the descriptive and predictive power of the spring-mass model
in running mechanics and the serious technical issues mentioned, the aim of this
study was to propose and validate a simple calculation method for assessing leg and
vertical stiffness during running. The computations inherent in the proposed method
are based on a few simple mechanical parameters: contact and flight times, forward
running speed, leg length, and body mass. We validated the method by comparing
leg and vertical stiffness values measured with a force platform to those obtained
using the proposed method during treadmill and overground running.

**Methods**

For practical reasons our study was divided into two different protocols, one aiming
to validate the presented method during treadmill running, the other during over­
ground running. However, in both cases the force platform and sine-wave method
stiffness values were each calculated in the same way. All participants gave their
informed consent to take part in those protocols.

Treadmill running: Eight young men (age 24 ± 2 yrs, height 1.78 ± 0.07 m,
body mass 76.0 ± 7.0 kg; mean ± _SD_ ) volunteered to participate in this study. They
were physical education students and experienced in treadmill running. After a 5-min
warm-up at 3.33 m·s \[–1\], they performed 30-s running bouts at 3.33, 3.89, 4.44, 5, 5.56,
6.11, and 6.67 m·s \[–1\] at their preferred step frequency (separated by 2 min of rest)
on a treadmill dynamometer (HEF Techmachine, Andrézieux-Bouthéon, France).
Using the same calibration procedure as Belli, Bui, Berger, Geyssant, and Lacour
(2001), we determined the treadmill’s static nonlinearity to be less than 0.5% and 1%,
respectively, in the vertical and horizontal directions. Natural vibration frequency
(treadmill hit with a hammer) were 147 Hz in the vertical direction and 135 Hz in
the anterior-posterior and mediolateral directions. Vertical ground reaction forces,
belt velocity, and flight and contact times were measured at a sampling frequency
of 500 Hz. All values were averaged for 10 consecutive steps for each velocity.

Measuring Stiffness During Running 169

_Overground running_ : 10 young men (age 23 ± 3 yrs, height 1.80 ± 0.05 m,
body mass 66.4 ± 5.3 kg) who were elite middle-distance runners volunteered to
run over a 10-m force platform (Kistler, Winterthur, Switzerland; natural frequency
higher than 150 Hz, horizontal to vertical cross-talk lower than 2%) at 4, 5, 6, and
7 m·s \[–1\] and at their maximal running velocity. Velocity was measured by two pairs
of photocells placed at each end of the force platform. Vertical ground reaction
forces and flight and contact times were measured for one step at each velocity at
a sampling rate of 1.8 kHz.

_Reference method. Vertical stiffness_ : The vertical stiffness _k_ vert (in kN·m \[–1\] )
was calculated as:

_k_ vert = _F_ max · ∆ _yc_ \[–1\] (1)

with _F_ max the maximal ground reaction force during contact (in kN) and ∆ _yc_ the
vertical displacement of the CM when it reaches its lowest point (in m), determined
by double integration of the vertical acceleration over time, as proposed by Cavagna
(1975). Figure 1 shows a typical example of force and vertical displacement of the
CM evolutions during contact.

_Leg stiffness_ : The stiffness of the leg spring _k_ leg (in kN·m \[–1\] ) was calculated
as follows:
_k_ leg = _F_ max · ∆ _L_ \[–1\] (2)

with ∆ _L_ the peak displacement of the leg spring (in m) calculated from the initial
leg length _L_ (great trochanter to ground distance in a standing position), running
velocity _v_ (in m·s \[–1\] ), and the contact time _t_ c (in s), as per Farley and Gonzales
(1996; Eq. 2 and 3):

∆ _L_ = _L_ – √ _L_ \[2\] – (–– _vt_ 2 _c_ ) \[2\] + ∆ _yc_ (3)

**Figure 1 — Typical measured (thick line) and modeled (dotted** **line) vertical force over**
**time during contact on treadmill running, and corresponding downward vertical CM**
**displacement (thin line) (velocity of 5 m·s** **\[–1\]** **, body mass of 68 kg).**

170 _Morin, Dalleau, et al._

_Sine-wave method. Model proposed_ : This method is based on a model used
by Dalleau et al. (2004) for vertical jumps, which considers the force as a func­
tion of time during contact to be a simple sine function (Alexander, 1989; Kram
& Dawson, 1998):
_F_ ( _t_ ) = _F_ maxsin(— _t_ π _c_ _t_ ) (4)

The validity of this postulate was checked by comparing areas under the mea­
sured and modeled _F_ ( _t_ ) curves for all steps analyzed (Figure 1). The mean absolute
bias was calculated as (Modeled – Force platform)/Force platform×100.

_Calculations_ : Complete calculations and assumptions are shown in the
Appendix section of this paper. ^

maximal force The modeled vertical stiffness _F_ ^ max over the modeled vertical CM displacement _k_ vert was calculated as the ratio of the modeled ∆y^c:

^

^ ^

^

^

^

_k_ vert = _F_ max · ∆ _yc_ \[–1\] (5)

^

^

π _tf_
2 _tc_

with _F_ max = _m_ g — (— +1) (6)

_m_ being the participant’s body mass (in kg), and _tf_ and _tc_, respectively, being the
flight and contact times (in s)

^

_tc_ \[2\]

^

_F_ max _tc_ \[2\]

and ∆ _y_ ^ _c_ = —— + g — max _c_ _c_ (7)

\[2\]

_m_ π \[2\]

8

^

The modeled leg stiffness _k_ leg was calculated as follows:

^

^ ^

_k_ leg = _F_ max · ∆ _L_ \[–1\] (8)

with ∆ _L_ ^ = _L_ – √ _L_ \[2\] – (—) _vtc_ \[2\] + ∆ _y_ ^ _c_ (9)

^ \[2\] _vtc_

^

2

the modeled leg length variation (in m).

The participant’s leg length was also modeled as: _L_ mod = 0.53 _h_ where _h_ is the
participant’s height (in m), according to the anthropometric equations of Winter
(1979), in order to check the validity of the presented stiffness calculation method
using leg length values obtained from participant’s height data.

In order to quantify the force platform-model values difference, we calculated
an absolute mean error bias as follows: Bias = (Modeled – Force platform)/Force
platform×100. The force platform-model relationships were further described by
means of linear regressions and calculation of the determination coefficient _R_ ².

We then performed an ANOVA with the Scheffé post hoc test in order to
check the eventual effect of velocity on the above-mentioned force platform-model
bias. The statistically significant level was set at 0.05.

**Results**

The bias between force platform and modeled _F_ (t) areas was 5.33% (ranging from
11.7% at 3.33 m·s \[–1\] to 1.7% at 6.67 m·s \[–1\] ) for treadmill running, 542 steps analyzed,
and 2.93% (ranging from 3.17% at 4 m·s \[–1\] to 2.33% at 7 m·s \[–1\] ) for overground
running, 50 steps analyzed.

Measuring Stiffness During Running 171

**Table 1 Main Mechanical Parameters Measured With Reference Method During**
**Treadmill Running (** _**M**_ **±** _**SD**_ **)**

Reference Modeled Bias (%)

∆ _yc_ (m) 0.05 ± 0.01 0.05 ± 0.02 3.28 ± 1.10

∆ _L_ (m) 0.20 ± 0.03 0.20 ± 0.03 0.93 ± 0.43

_F_ max (kN) 2.05 ± 0.34 1.91 ± 0.32 6.93 ± 2.52
_k_ vert (kN·m \[–1\] ) 37.70 ± 8.84 37.74 ± 8.87 0.12 ± 0.53
_k_ leg (kN·m \[–1\] ) 10.37 ± 2.34 9.75 ± 2.19 6.05 ± 3.02

_Note_ : Measured with reference method, corresponding values calculated with proposed
method and error bias values in between. Values presented are averaged for all partici­
pants and all velocities.

**Table 2 Main Mechanical Parameters Measured With Reference Method During**
**Overground Running (** _**M**_ **±** _**SD**_ **)**

Reference Modeled Bias (%)

∆ _yc_ (m) 0.05 ± 0.01 0.05 ± 0.01 2.34 ± 2.42

∆ _L_ (m) 0.16 ± 0.02 0.16 ± 0.02 0.67 ± 1.09

_F_ max (kN) 2.13 ± 0.21 2.06 ± 0.24 3.24 ± 2.08
_k_ vert (kN·m \[–1\] ) 51.39 ± 21.46 50.21 ± 20.40 2.30 ± 1.63
_k_ leg (kN·m \[–1\] ) 13.28 ± 1.85 12.95 ± 2.13 2.54 ± 1.16

_Note_ : Measured with reference method, corresponding values calculated with proposed
method and error bias values in between. Values presented are averaged for all partici­
pants and all velocities.

The values of the different mechanical parameters measured and modeled and
the reference-model bias are shown in Tables 1 and 2 for treadmill and overground
running, respectively. For the vertical and leg stiffness, we obtained reference-model
error biases of 0.12% (ranging from 1.53% at 6.67 m·s \[–1\] to 0.07% at 6.11 m·s \[–1\] ) and
of 6.05% (from 9.82% at 3.33 m·s \[–1\] to 3.88% at 6.67 m·s \[–1\] ), respectively, during
treadmill running. During overground running the bias was 2.30% (from 3.64% at
5 m·s \[–1\] to 0.25% at 6 m·s \[–1\] ) for the vertical stiffness, and 2.54% (from 3.71% at 5
m·s \[–1\] to 1.11% at maximal velocity) for leg stiffness.

Further, the reference-model linear regressions were significant ( _p_ \< 0.01; _R_ ²
= 0.89 to 0.98) for both vertical and leg stiffness either on the treadmill or during
overground running (Figures 2 and 3, respectively).

The changes in reference and modeled values of stiffness with running veloci­
ties are reported in Figure 4 for treadmill and overground running. The ANOVA
and the Scheffé post hoc test demonstrated for treadmill running a significant dif­

172 _Morin, Dalleau, et al._

**Reference vertical stiffness (kN·m** **\[–1\]** **)**

**Reference leg stiffness (kN·m** **\[–1\]** **)**

**Figure 2 — Significant reference-model linear regressions (** _**p**_ **\< 0.01) obtained during**
**treadmill running for vertical stiffness (upper panel) and leg stiffness (lower panel)**
**compared to the identity line. Each dot represents a mean value of stiffness for a par­**
**ticipant at the corresponding velocity.**

Measuring Stiffness During Running 173

**Reference vertical stiffness (kN·m** **\[–1\]** **)**

**Reference leg stiffness (kN·m** **\[–1\]** **)**

**Figure 3 — Significant reference-model linear regressions (** _**p**_ **\< 0.01) obtained during**
**overground running for vertical stiffness (upper panel) and leg stiffness (lower panel)**
**compared to the identity line. Each dot represents the value of stiffness of the step**
**analyzed for each participant at the corresponding velocity.**

174 _Morin, Dalleau, et al._

**Velocity (m·s** **\[–1\]** **)**

**Velocity (m·s** **\[–1\]** **)**

**Figure 4 — Changes in the modeled and reference vertical and leg stiffness with run­**
**ning velocity during treadmill running (upper panel) and overground running (lower**
\*_panel). _Significant (__ _**p**_ **\< 0.05) difference in reference-model bias obtained by ANOVA**
**and Scheffé post hoc test.**

Measuring Stiffness During Running 175

ference ( _p_ \< 0.05) between the bias in leg stiffness assessment at 3.33 m·s \[–1\] and
that obtained at the four highest velocities. For overground running, a significant
difference was observed on the vertical stiffness bias ( _p_ \< 0.05) obtained at 6 m·s \[–1\]
and at the maximal velocity (Figure 4).

The leg length calculation using Winter’s equation led to a mean error bias of
1.94 ± 1.51%, and the linear regression between the measured leg length and that
obtained using Winter’s model was significant ( _R_ ² = 0.89; _p_ \< 0.01).

**Discussion**

The values of the different mechanical parameters obtained in this study—verti­
cal ground reaction forces, displacements, and stiffness—are in line with those of
studies about the spring-mass model in running (Arampatzis et al., 1999; Blickhan,
1989; Farley & Gonzales, 1996; Ferris et al., 1998; He et al., 1991; McMahon et al.,
1987; McMahon & Cheng, 1990). It should be noted that we obtained slight differ­
ences in displacements and vertical and leg stiffness between our two experimental
protocols (treadmill and overground running), due to the different running abilities
of the two populations in these two parts of the study.

Indeed, highly trained middle-distance runners who performed the force plat­
form protocol showed lower CM displacement and leg length change and higher
vertical and leg stiffness than the nonspecialists who volunteered to perform the
treadmill protocol (e.g _._, leg stiffness: 10.37 ± 2.34 kN·m \[–1\] for the treadmill protocol
group vs. 13.28 ± 1.85 kN·m \[–1 \] for overground runners). This is in line with the study
of Mero and Komi (1986), who observed higher “apparent spring constants” of the
support leg and lower CM displacement during running in highly trained sprinters
compared to less-skilled ones (Luhtanen & Komi, 1980) or marathon runners (Ito,
Komi, Sjödin, Bosco, & Karlsson, 1983).

The stiffness vs. velocity patterns (Figure 4), i.e., the increase in vertical
stiffness and the constancy of leg stiffness with increasing velocity either on the
treadmill or in overground conditions, has been previously noted in the literature
(He et al., 1991; McMahon et al., 1987).

_Validity of the proposed sine-wave method_ : The aim of this study was to
provide a calculation method based on a few simple parameters allowing vertical
and leg stiffness to be assessed during treadmill and overground running without
a force platform. The low bias obtained between force platform and model values
(from 0.12% to 6%), and the high determination coefficients (from 0.89 to 0.98, _p_
\< 0.01), demonstrate the validity of this calculation method during both treadmill
and overground running. Furthermore, the validity of this method was tested for a
wide range of velocities (i.e., from 3.33 to 6.67 m·s \[–1\] on the treadmill and 4 m·s \[–1\]
to maximal velocity on the force platform) with runners of different ability levels,
from nonspecialists to highly trained middle-distance runners, all giving acceptable
results (Figures 2 and 3). This may allow us to use the proposed method during
submaximal to maximal velocity running, with either nonspecialists or elite athletes,
in field conditions. It should be also noted that the mechanical parameter input
to the model (maximal force, CM displacement, leg length change) also showed
acceptable reference-model bias (0.67 to 6.93%, Tables 1 and 2).

_Basis postulate and assumptions_ : The basis postulate of this study was that
the _F_ ( _t_ ) curve can be fitted by means of a simple sine function. The validity of this
sine modeling, recently used in a study aimed at validating a stiffness measuring

176 _Morin, Dalleau, et al._

method during hopping (Dalleau, Belli, Viale, Lacour, & Bourdin, 2004), was
checked by comparing areas under _F_ ( _t_ ) curves for all steps analyzed on the treadmill
and on the force plate, and we obtained low error bias values (5.33% and 2.93%,
respectively). On the treadmill the accuracy of this sine modeling was improved
at faster velocities, the bias ranging from 11.7% at 3.33 m·s \[–1\] to only 1.7% at 6.67
m·s \[–1\] . This was probably due to the alteration of the passive impact peak in the
vertical ground reaction force at low velocity and to an _F_ ( _t_ ) curve more closely
approximating a sine curve at faster velocities. This could explain the significant
effect of velocity on reference-model bias in leg stiffness observed between that
obtained at 3.33 m·s \[–1\] and that at the four highest velocities (Figure 4, upper panel),
the accuracy of the basic sine-wave postulate increasing at faster velocities on the
treadmill. To the contrary, this velocity effect on the bias was not observed during
overground running.

The bias in _F_ ( _t_ ) curve fitting by the sine function was rather constant, and the
previously mentioned velocity effect on reference-model bias was only significant ( _p_
= 0.043) in vertical stiffness between that obtained at 6 m·s \[–1\] and that at the maximal
velocity (Figure 4, lower panel). This smaller effect of velocity may be explained
by the fact that _F_ ( _t_ ) curves of elite level “forefoot striking” runners showed smaller
or no passive impact peaks, whatever the velocity, with shorter contact times and
_F_ ( _t_ ) plot shapes closer to a sine-wave (Nilsson & Thorstensson, 1989).

_Sensitivity analysis_ : In order to further determine the influence of the dif­
ferent mechanical parameters constituting the presented model on the vertical and
leg stiffness calculated, we performed a sensivity analysis (Figure 5). It was then
possible to observe the relative influence of each mechanical parameter on the
calculated stiffness values. It should be noted that the most sensitive parameter, for
both vertical and leg stiffness estimates, is the contact time. Its variation influences
the stiffness in a proportion of about 1 to 2, i.e., for instance a 10% reduction in
contact time leads, according to this model, to a 20% increase in vertical stiffness
or even 25% in leg stiffness. All the other parameters have a 1 : 1 weight or even
less, especially anthropometrical parameters of body mass and leg length.

Therefore, although the legs are not stiff either at landing or takeoff, resulting
in a slight overestimation of leg length (Arampatzis et al., 1999), the influence of
such a phenomenon on the accuracy of the stiffness calculations was not important.
In addition, the results of the present study showed that the leg length value used
in this sine-wave model can be obtained using anthropometric equations, on the
basis of the individual’s height, without significant changes in the stiffness values
obtained. Furthermore, a recent study did not find any significant variation in the
stiffness values obtained with the proposed method, using an estimated value of leg
length from the participant’s height according to Winter’s model (Winter, 1979),
showing that this parameter is not crucial for improving the accuracy of the sinewave model (Jeannin, 2003).

This model also assumes a constant point-of-force application on the ground
during the entire contact phase. However, the location of the point-of-force applica­
tion was shown to move forward by about 0.16 m (Lee & Farley, 1998), and this
constitutes another limitation of the simplest spring-mass model.

Finally, it is worth noting that the limits of the proposed sine-wave method are
also those inherent in the use of any theoretical spring-mass model, i.e., the human
lower limb is not a true linear spring in a physical sense. This point has been widely
discussed elsewhere (Blickhan, 1989; Farley & Gonzales, 1996; Ferris, Louie, &

Measuring Stiffness During Running 177

**Parameters variation (%)**

**Parameters variation (%)**

**Figure 5 — Sensitivity analysis: Variations of the different mechanical parameters**
**constituting the equation’s model plotted against the corresponding leg stiffness (upper**
**panel) and vertical stiffness (lower panel) variations.**

Farley, 1998; He et al., 1991; McMahon & Cheng, 1990). Even if one prefers the
term “quasi-stiffness” (Latash & Zatsiorsky, 1993), the simplicity and predictive
power of the spring-mass model in studies aimed at understanding and analyzing
human running performance outweigh the limitations.

The equations based on a force-time curve sine modeling allow these calcu­
lations from simple mechanical parameters of flight and contact times, leg length,
body mass, and running velocity. The reference-model biases on calculated stiff­
ness were acceptable for a wide range of velocities, different levels of runners, and

178 _Morin, Dalleau, et al._

either on a treadmill dynamometer or overground. To conclude, this new method
may allow researchers to measure and to understand the influence of leg stiffness
on performance in field running conditions and also to improve track & field coach­
ing and training.

**References**

Alexander, R.M. (1989). On the synchronization of breathing with running in wallabies ( _Mac­_

_ropus spp_ .) and horses ( _Equus caballus_ ). _Journal of Zoology (London)_, **218**, 69-85.
Alexander, R.M. (1992). A model of bipedal locomotion on compliant legs. _Philosophical_

_Transactions of the Royal Society of London_, **B338**, 189-198.
Arampatzis, A., Brüggemann, G.-P., & Metzler, V. (1999). The effect of speed on leg stiffness

and joint kinetics in human running. _Journal of Biomechanics_, **32**, 1349-1353.
Belli, A., Bui P., Berger, A., Geyssant, A., & Lacour, J.-R. (2001). A treadmill ergometer for

three-dimensional ground reaction forces measurement during walking. _Journal of_
_Biomechanics_, **34**, 105-112.
Blickhan, R. (1989). The spring-mass model for running and hopping. _Journal of Biome­_

_chanics_, **22**, 1217-1227.
Cavagna, G.A. (1975). Force platforms as ergometers. _Journal of Applied Physiology_, **39**,

174-179.

Cavagna, G.A., Heglund, N.C., & Taylor, C.R. (1977). Mechanical work in terrestrial loco­

motion: Two basic mechanisms for minimizing energy expenditure. _American Journal_
_of Physiology_, **233**, R243-R261.
Cavagna, G.A., Saibene, F.P., & Margaria, R. (1964). Mechanical work in running. _Journal_

_of Applied Physiology_, **19**, 249-256.
Dalleau, G., Belli, A., Bourdin, M., & Lacour, J.-R. (1998). The spring-mass model and

the energy-cost of treadmill running. _European Journal of Applied Physiology_, **77**,
257-263.

Dalleau, G., Belli, A., Viale, F., Lacour, J.-R., & Bourdin, M. (2004). A simple method

for field measurement of leg stiffness in hopping. _International Journal of Sports_
_Medicine_, **25**, 170-176.
Farley, C.T., Blickhan, R., Saito, J., & Taylor, C.R. (1991). Hopping frequency in humans:

A test of how springs set stride frequency in bouncing gaits. _Journal of Applied_
_Physiology_, **716**, 2127-2132.
Farley, C.T., & Gonzalez, O. (1996). Leg stiffness and stride frequency in human running.

_Journal of Biomechanics_, **29**, 181-186.
Ferris, D., Louie, M., & Farley, C.T. (1998). Running in the real world: Adjusting leg stiffness

for different surfaces. _Proceedings of the Royal Society of London_, **265**, 898-994.
He, J., Kram, R., & McMahon, T. (1991). Mechanics of running under simulated low gravity.

_Journal of Applied Physiology_, **71**, 863-870.
Ito, A., Komi, P.V., Sjödin, B., Bosco, C., & Karlsson, J. (1983). Mechanical efficiency

of positive work in running at different speeds. _Medicine and Science in Sports and_
_Exercise_, **15**, 299-308.
Jeannin, T. (2003). _Mesure des paramètres mécaniques de la course sur tapis roulant et sur_

_le terrain_ \[Measurement of mechanical parameters during treadmill and overground
running\]. Saint-Etienne, France: University of Saint-Etienne.
Kram, R., & Dawson, T.J. (1998). Energetics and biomechanics of locomotion by red kan­

garoos (Macropus rufus). _Comparative Biochemistry and Physiology_, **120**, 41-49.
Latash, M.L., & Zatsiorsky, V.M. (1993). Joint stiffness: Myth or reality? _Human Movement_

_Studies_, **12**, 653-692.

Measuring Stiffness During Running 179

Lee, C., & Farley, C.T. (1998). Determinants of the center of mass trajectory in human walk­

ing and running. _Journal of Experimental Biology_, **201**, 2935-2944.
Luhtanen, P., & Komi, P.V. (1980). Force-, power-, and elasticity-velocity relationships in

walking, running and jumping. _European Journal of Applied Physiology_, **44**, 279-289.
McMahon, T.A., & Cheng, G.C. (1990). The mechanics of running: How does stiffness

couple with speed? _Journal of Biomechanics_, **23**, 65-78.
McMahon, T.A., Valiant, G., & Frederick, E.C. (1987). Groucho running. _Journal of Applied_

_Physiology_, **62**, 2326-2337.
Mero, A., & Komi, P.V. (1986). Force-, EMG-, and elasticity-velocity relationships at sub­

maximal, maximal and supramaximal running speeds in sprinters. _European Journal_
_of Applied Physiology_, **55**, 553-561.
Nilsson, J., & Thorstensson, A. (1989). Ground reaction forces at different speeds of human

walking and running. _Acta Physiologica Scandinavica_, **136**, 217-227.
Winter, D.A. (1979). _Biomechanics of human movement_ . New York: Wiley & Sons.

**APPENDIX**

_**Modeled vertical stiffness computations**_

^

The modeled vertical stiffness _k_ vert was calculated as:

^ ^ ^

_k_ vert = _F_ max · ∆ _yc_ \[–1\] (5)

with _F_ ^max the modeled maximal force and ∆ _y_ ^ _c_ the modeled vertical peak displace­
ment of the center of mass (CM) during contact.

^

_F_ max _computations_

The pattern of vertical ground reaction force over time was modeled using the
following equation:
_F_ ( _t_ ) = _F_ max · sin(— _t_ π _c_          - _t_ ) (4)

with _F_ max the peak force value and _tc_ the contact time.

From this equation, the momentum change during contact is:

## ∫

_tc_

## t 0 \[ F ( t ) – m g\] · dt = m ∆ u = m g tf (A10)

_t_ 0

with _m_ the participant’s body mass, _u_ the vertical velocity, g the gravity accelera­
tion, and _tf_ the mean flight time (mean of flight times before and after contact).
Substituting Eq. A4 in Eq. A10 gives:

## ∫

_tc_ π

## t 0 \[ F max · sin(— · t t ) – m g\] · dt = m ∆ u = m g tf (A11)

_t_ 0

π

_tc_

π _tc_

_t_ )\]

_tc_ _t_ 0

_t_ π _c_ _m_ g ( _tf_ + _t_

_tc_ π

π _tc_

## \[– F max — cos (— · c π t )\] – c m g tc = m g tf (A12)

2 _F_ max — _c_ _m_ g ( _tf_ + _tc_ ) (A13)

The modeled peak force during contact is then obtained as:

^

π

2

## F max = m g — π (— + 1 f ) (6)

_tf_
_tc_

180 _Morin, Dalleau, et al._

∆ _y_ ^ _c_ _computations_

Based on Eq. A4 and according to the fundamental law of dynamics, vertical velocity
is obtained by integrating the vertical acceleration of the CM during contact:

_u_ ( _t_ ) = ∫

## tc \[—– – g F ( t ) \] · dt + u ( t 0) (A14)

_F_ ( _t_ )

_t_ 0

_m_

_u_ ( _t_ 0) being the downward vertical velocity at the beginning of contact.

_u_ ( _t_ ) = ∫

^

## ttc 0\[ F —–– sin max (— · π t ) – g\] · dt + u ( t 0) (A15)

_F_ max

π

_tc_

_t_ 0

_m_

## ( t π c

_tc_

## π (

^

_F_ max

_tc_

_t_ 0

## u ( t ) = \[– —– — cos max tc (— · π t )\] – g t + u ( t 0) (A16)

_m_

Knowing that the vertical velocity is nil at the time of half-contact:^

_tc_

π

_tc_
2

— _t_ 2 _c_

= —– — – g— + _Fm_ max _t_ π _c_ _t_ 2 _c_

^

_F_ max _tc_

_F_ max

## u (— tc ) = —– — – g— + max tc tc u ( t 0) = 0 (A17)

_m_

^

—– — + max _c_ _u_ ( _t_ 0) = g— _c_ (A18)

_m_

_tc_

π

The final expression of vertical velocity during contact being:

^

_F_ max

_tc_

π

π

_tc_

## u ( t ) = – —– — cos max tc (— · π t ) – g t + g— tc (A19)

_tc_
2

_m_

Integrating this vertical velocity over time, vertical displacement can be obtained:

_tc_

_y_ ( _t_ ) = ∫ _u_ ( _t_ ) · _dt_ + _y_ ( _t_ 0) (A20)

_tc_

_t_ 0

_u_ ( _t_ ) · _dt_ + _y_ ( _t_ 0) (A20)

with _y_ ( _t0_ ) the vertical position of the CM at the beginning of contact.

Assuming _y_ ( _t_ 0) = 0 and substituting Eq. A19 in Eq. A20:

^

_y_ ( _t_ ) = ∫

max _c_ π _tc_

## \[– —– — cos (— · t ) – g t + g—\] · dt (A21)

max _tc_ π _tc_

## \[^– —– — cos m m (— · tc t ) – g t + g—2

_F_ max _t_ \[2\] π 1 _tc_

_tc_

_t_ 0

_m_

_F_ max

_tc_

_m_

π

_tc_

^

π

_tc_

1

2

_tc_ + g— _tc_ _t_ (A22)

## – —– — sin m max t π c \[2\] (— · t π c t ) – — g12 t \[2\] \] ttc 0 + g— t 2 c

^

_F_ max _t_ \[2\] π 1 _t_

## y ( t ) = \[– —– — sin max tc (— · π t ) – — g1 t \[2\] \]

\[2\]

_m_

_tc_ \[2\]

π \[2\]

_t_ 0

^

_tc_
2

## y ( t ) = – —- — sin max tc (— · π t ) – — g t \[2\] + g— tc t (A23)

\[2\]

_m_

## tc \[2\] ( π

π \[2\] _tc_

1

2

The total CM displacement at the time of half contact, i.e., for _t_ = _tc_ / 2 is then:

^

_tc_ \[2\]

π \[2\]

_tc_ \[2\]

8

^

_F_ max

∆ _y_ ^ _c_ = – —- — + g— max _c_ _c_ (7)

_m_

_Modeled leg stiffness computations_

^

The modeled leg stiffness _k_ leg was calculated as:

^ ^ ^

_k_ leg = _F_ max · ∆ _L_ \[–1\] (8)

^

with ∆ _L_ the modeled leg peak displacement during contact.

^

∆ _L_ _computations_
∆ _L_ ^ was obtained on the basis of the spring-mass model’s typical equations and
assumptions (Farley & Gonzales, 1996; McMahon & Cheng, 1990):

^

^

^

## ∆ L ^ = L – √ L \[2\] – (—– vtc )

_vtc_

2 + ∆ _y_ ^ _c_ (9)

^ _vt_ ^

2

_L_ being the participant’s leg length and _v_ the constant horizontal velocity.
